@@ -328,6 +328,13 @@ class Deal(OfDictClass):
     def set_current_price(self, current_price: Union[str, float]):
         self['current_price'] = current_price
 
+    @ThreeCommasParser.parsed(float)
+    def get_take_profit_price(self) -> Union[str, float]:
+        return self.get('take_profit_price')
+
+    def set_take_profit_price(self, take_profit_price: Union[str, float]):
+        self['take_profit_price'] = take_profit_price
+
     @ThreeCommasParser.parsed(float)
     def get_final_profit_percentage(self) -> Union[str, float]:
         return self.get('final_profit_percentage')
@@ -335,6 +342,13 @@ class Deal(OfDictClass):
     def set_final_profit_percentage(self, final_profit_percentage: Union[str, float]):
         self['final_profit_percentage'] = final_profit_percentage
 
+    @ThreeCommasParser.parsed(float)
+    def get_actual_profit_percentage(self) -> Union[str, float]:
+        return self.get('actual_profit_percentage')
+
+    def set_actual_profit_percentage(self, actual_profit_percentage: Union[str, float]):
+        self['actual_profit_percentage'] = actual_profit_percentage
+
     def get_bot_name(self) -> str:
         return self.get('bot_name')
 
@@ -402,12 +416,19 @@ class Deal(OfDictClass):
     def set_strategy(self, strategy: str):
         self['strategy'] = strategy
 
-    def get_reserved_quote_funds(self) -> int:
+    @ThreeCommasParser.parsed(float)
+    def get_reserved_quote_funds(self) -> Union[str, float]:
         return self.get('reserved_quote_funds')
 
-    def set_reserved_quote_funds(self, reserved_quote_funds: int):
+    def set_reserved_quote_funds(self, reserved_quote_funds: Union[str, float]):
         self['reserved_quote_funds'] = reserved_quote_funds
 
+    def get_buy_steps(self) -> List[dict]:
+        return self.get('buy_steps')
+
+    def set_buy_steps(self, buy_steps: List[dict]):
+        self['buy_steps'] = buy_steps
+
     @ThreeCommasParser.lazy_parsed(List[BotEvent])
     def get_bot_events(self) -> Union[List[dict], List[BotEvent]]:
         return self.get('bot_events')
@@ -1144,3 +1165,253 @@ class PairsBlackList(OfDictClass):
 
     def set_pairs(self, pairs: List[str]):
         self['pairs'] = pairs
+
+
+class SmartTradeV2(OfDictClass):
+
+    def get_id(self) -> int:
+        return self.get('id')
+
+    def set_id(self, id: int):
+        self['id'] = id
+
+    def get_version(self) -> int:
+        return self.get('version')
+
+    def set_version(self, version: int):
+        self['version'] = version
+
+    def get_account(self) -> dict:
+        return self.get('account')
+
+    def set_account(self, account: dict):
+        self['account'] = account
+
+    def get_pair(self) -> str:
+        return self.get('pair')
+
+    def set_pair(self, pair: str):
+        self['pair'] = pair
+
+    def is_instant(self) -> bool:
+        return self.get('instant')
+
+    def set_instant(self, instant: bool):
+        self['instant'] = instant
+
+    def get_status(self) -> dict:
+        return self.get('status')
+
+    def set_status(self, status: dict):
+        self['status'] = status
+
+    def get_leverage(self) -> dict:
+        return self.get('leverage')
+
+    def set_leverage(self, leverage: dict):
+        self['leverage'] = leverage
+
+    def get_position(self) -> dict:
+        return self.get('position')
+
+    def set_position(self, position: dict):
+        self['position'] = position
+
+    def get_take_profit(self) -> dict:
+        return self.get('take_profit')
+
+    def set_take_profit(self, take_profit: dict):
+        self['take_profit'] = take_profit
+
+    def get_stop_loss(self) -> dict:
+        return self.get('stop_loss')
+
+    def set_stop_loss(self, stop_loss: dict):
+        self['stop_loss'] = stop_loss
+
+    def get_reduce_funds(self) -> dict:
+        return self.get('reduce_funds')
+
+    def set_reduce_funds(self, reduce_funds: dict):
+        self['reduce_funds'] = reduce_funds
+
+    def get_market_close(self) -> dict:
+        return self.get('market_close')
+
+    def set_market_close(self, market_close: dict):
+        self['market_close'] = market_close
+
+    def get_note(self) -> str:
+        return self.get('note')
+
+    def set_note(self, note: str):
+        self['note'] = note
+
+    def is_skip_enter_step(self) -> bool:
+        return self.get('skip_enter_step')
+
+    def set_skip_enter_step(self, skip_enter_step: bool):
+        self['skip_enter_step'] = skip_enter_step
+
+    def get_data(self) -> dict:
+        return self.get('data')
+
+    def set_data(self, data: dict):
+        self['data'] = data
+
+    def get_profit(self) -> dict:
+        return self.get('profit')
+
+    def set_profit(self, profit: dict):
+        self['profit'] = profit
+
+    def get_margin(self) -> dict:
+        return self.get('margin')
+
+    def set_margin(self, margin: dict):
+        self['margin'] = margin
+
+    def is_position_not_filled(self) -> bool:
+        return self.get('is_position_not_filled')
+
+    def set_is_position_not_filled(self, is_position_not_filled: bool):
+        self['is_position_not_filled'] = is_position_not_filled
+
+
+class SmartTradeV2Trade(OfDictClass):
+
+    def get_id(self) -> int:
+        return self.get('id')
+
+    def set_id(self, id: int):
+        self['id'] = id
+
+    @ThreeCommasParser.parsed(float)
+    def get_average_price(self) -> Union[str, float]:
+        return self.get('average_price')
+
+    def set_average_price(self, average_price: Union[str, float]):
+        self['average_price'] = average_price
+
+    def get_follow_price_type(self) -> str:
+        return self.get('follow_price_type')
+
+    def set_follow_price_type(self, follow_price_type: str):
+        self['follow_price_type'] = follow_price_type
+
+    @ThreeCommasParser.parsed(float)
+    def get_initial_amount(self) -> Union[str, float]:
+        return self.get('initial_amount')
+
+    def set_initial_amount(self, initial_amount: Union[str, float]):
+        self['initial_amount'] = initial_amount
+
+    @ThreeCommasParser.parsed(float)
+    def get_initial_total(self) -> Union[str, float]:
+        return self.get('initial_total')
+
+    def set_initial_total(self, initial_total: Union[str, float]):
+        self['initial_total'] = initial_total
+
+    def get_order_side(self) -> str:
+        return self.get('order_side')
+
+    def set_order_side(self, order_side: str):
+        self['order_side'] = order_side
+
+    def get_order_type(self) -> str:
+        return self.get('order_type')
+
+    def set_order_type(self, order_type: str):
+        self['order_type'] = order_type
+
+    def get_pair(self) -> str:
+        return self.get('pair')
+
+    def set_pair(self, pair: str):
+        self['pair'] = pair
+
+    @ThreeCommasParser.parsed(float)
+    def get_realised_amount(self) -> Union[str, float]:
+        return self.get('realised_amount')
+
+    def set_realised_amount(self, realised_amount: Union[str, float]):
+        self['realised_amount'] = realised_amount
+
+    @ThreeCommasParser.parsed(float)
+    def get_realised_total(self) -> Union[str, float]:
+        return self.get('realised_total')
+
+    def set_realised_total(self, realised_total: Union[str, float]):
+        self['realised_total'] = realised_total
+
+    def get_status(self) -> str:
+        return self.get('status')
+
+    def set_status(self, status: str):
+        self['status'] = status
+
+    def get_trade_purpose(self) -> str:
+        return self.get('trade_purpose')
+
+    def set_trade_purpose(self, trade_purpose: str):
+        self['trade_purpose'] = trade_purpose
+
+    def is_trailing_enabled(self) -> bool:
+        return self.get('trailing_enabled')
+
+    def set_trailing_enabled(self, trailing_enabled: bool):
+        self['trailing_enabled'] = trailing_enabled
+
+    def get_trigger_type(self) -> str:
+        return self.get('trigger_type')
+
+    def set_trigger_type(self, trigger_type: str):
+        self['trigger_type'] = trigger_type
+
+    @ThreeCommasParser.parsed_timestamp
+    def get_created_at(self) -> Union[str, datetime.datetime]:
+        return self.get('created_at')
+
+    def set_created_at(self, created_at: str):
+        self['created_at'] = created_at
+
+    @ThreeCommasParser.parsed_timestamp
+    def get_updated_at(self) -> Union[str, datetime.datetime]:
+        return self.get('updated_at')
+
+    def set_updated_at(self, updated_at: str):
+        self['updated_at'] = updated_at
+
+    @ThreeCommasParser.parsed(float)
+    def get_realised_percentage(self) -> Union[str, float]:
+        return self.get('realised_percentage')
+
+    def set_realised_percentage(self, realised_percentage: Union[str, float]):
+        self['realised_percentage'] = realised_percentage
+
+    @ThreeCommasParser.parsed(float)
+    def get_initial_price(self) -> Union[str, float]:
+        return self.get('initial_price')
+
+    def set_initial_price(self, initial_price: Union[str, float]):
+        self['initial_price'] = initial_price
+
+    @ThreeCommasParser.parsed(float)
+    def get_realised_price(self) -> Union[str, float]:
+        return self.get('realised_price')
+
+    def set_realised_price(self, realised_price: Union[str, float]):
+        self['realised_price'] = realised_price
+
+    def is_cancelable(self) -> bool:
+        return self.get('cancelable')
+
+    def set_cancelable(self, cancelable: bool):
+        self['cancelable'] = cancelable
+
+    def is_force_processable(self) -> bool:
+        return self.get('force_processable')
+
+    def set_force_processable(self, force_processable: bool):
+        self['force_processable'] = force_processable
