@@ -2,7 +2,7 @@ from src.three_commas.error import ThreeCommasError
 import json
 
 
-def read_error(file_path) -> ThreeCommasError:
+def read_error_from_json(file_path) -> ThreeCommasError:
     with open(file_path, 'r+') as f:
         error = json.loads(f.read())
         error_model = ThreeCommasError(error)
@@ -10,7 +10,7 @@ def read_error(file_path) -> ThreeCommasError:
 
 
 def test_bo_to_small_tc_error_with_pair():
-    error = read_error('test/sample_data/errors/bo_too_small_with_pair.json')
+    error = read_error_from_json('test/sample_data/errors/bo_too_small_with_pair.json')
 
     assert error.is_base_order_to_small_error()
     bo_error = error.get_base_order_to_small_error()
@@ -20,7 +20,7 @@ def test_bo_to_small_tc_error_with_pair():
 
 
 def test_multiple_bo_error():
-    error = read_error('test/sample_data/errors/multiple_bo_so_errors.json')
+    error = read_error_from_json('test/sample_data/errors/multiple_bo_so_errors.json')
 
     bo_error = error.get_base_order_to_small_error()
     assert len(bo_error) == 4
@@ -29,7 +29,7 @@ def test_multiple_bo_error():
 
 
 def test_bo_to_small_tc_error_no_pair():
-    error = read_error('test/sample_data/errors/bo_too_small_no_pair.json')
+    error = read_error_from_json('test/sample_data/errors/bo_too_small_no_pair.json')
 
     bo_error = error.get_base_order_to_small_error()
     assert bo_error[0].amount == 9.4674
@@ -37,7 +37,7 @@ def test_bo_to_small_tc_error_no_pair():
 
 
 def test_no_bo_error():
-    error = read_error('test/sample_data/errors/signature_invalid.json')
+    error = read_error_from_json('test/sample_data/errors/signature_invalid.json')
 
     bo_error = error.get_base_order_to_small_error()
     assert len(bo_error) == 0
@@ -49,11 +49,11 @@ def test_no_bo_error():
 
 
 def test_api_key_invalid_or_expired():
-    error = read_error('test/sample_data/errors/api_key_invalid_or_expired_error.json')
+    error = read_error_from_json('test/sample_data/errors/api_key_invalid_or_expired_error.json')
     assert error.is_api_key_invalid_or_expired()
 
 
 def test_api_key_has_no_permission_error():
-    error = read_error('test/sample_data/errors/api_key_has_no_permission_error.json')
+    error = read_error_from_json('test/sample_data/errors/api_key_has_no_permission_error.json')
     assert error.is_api_key_has_no_permission_error()
 
